@@ -1,10 +1,16 @@
 package Moose::Autobox::Ref;     
 use Moose::Role 'with';
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 with 'Moose::Autobox::Defined';
 
+sub dump {
+    my $self = shift;
+    require Data::Dumper;
+    return Data::Dumper::Dumper($self);
+}
+
 1;
 
 __END__
@@ -25,6 +31,8 @@ This is a role to describes a reference value.
 
 =item B<meta>
 
+=item B<dump>
+
 =back
 
 =head1 BUGS
